using System;
using System.Collections.Generic;
using System.Text;
using Utils.DataBase;
using System.Data;
using PhoenixDLL.Class.Managers;
using PhoenixDLL.Class;

namespace PhoenixDLL.Class
{
    /// <summary>
    /// Class which manages the presence of the patients of the today's rendez-vous
    /// </summary>
    class TimeCardManager
    {
        #region Variables
        /// <summary>
        /// Patient which has meetings today
        /// </summary>
        private PatientManager vPatientManager;
        /// <summary>
        /// Meetings the patient has today
        /// </summary>
        private MeetingManager[] vMeetingList;
        /// <summary>
        /// Sql manager
        /// </summary>
        private OleDbSql SqlManager = new OleDbSql(Options.Instance.Path);
        private bool vHasRendezVous = false;
        #endregion

        #region Constructors
        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="_PatientManager">The patient</param>
        /// <exception cref="ArgumentException">If the ID is negative or does not link a patient</exception>
        public TimeCardManager(PatientManager _PatientManager)
        {
            if (vPatientManager.IDPatient < 0)
                throw new ArgumentException("The ID cannot be negative!");
            vPatientManager = _PatientManager;
            this.CalculateMeetings();
        }
        #endregion

        #region Methods
        /// <summary>
        /// Calculate the meetings the patient has today
        /// </summary>
        private void CalculateMeetings()
        {
            SqlManager.SqlQuery = "SELECT * FROM Rendez-Vous WHERE ID_Patient = " + vPatientManager.IDPatient
                + " AND Debut >= Now()" + ";";
            DataSet ds = new DataSet();
            int Rows = SqlManager.ExecuteSql(ref ds);
            if (Rows > 0)
                this.vHasRendezVous = true;
            else
                this.vHasRendezVous = false;

            vMeetingList = new MeetingManager[ds.Tables[0].Rows.Count];
            for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
            {
                vMeetingList[i].Came = (bool)ds.Tables[0].Rows[i]["came_to_rdv"];
                vMeetingList[i].End = (DateTime)ds.Tables[0].Rows[i]["Fin"];
                vMeetingList[i].IDMeeting = (int)ds.Tables[0].Rows[i]["id_Rdv"];
                vMeetingList[i].Message = (string)ds.Tables[0].Rows[i]["Message"];
                vMeetingList[i].Patient = PatientManager.Create((int)ds.Tables[0].Rows[i]["id_patient"]);
                vMeetingList[i].Payed = (bool)ds.Tables[0].Rows[i]["a_paye"];
                vMeetingList[i].Start = (DateTime)ds.Tables[0].Rows[i]["Debut"];
                vMeetingList[i].Title = (string)ds.Tables[0].Rows[i]["Titre"];
            }
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets the patient which has meetings today
        /// </summary>
        public PatientManager PatientManager
        {
            get { return vPatientManager; }            
        }
        /// <summary>
        /// Gets the meetings the patient has today
        /// </summary>
        public MeetingManager[] Meetings
        {
            get { return this.vMeetingList; }            
        }
        /// <summary>
        /// Gets a value wich indicates wheter the patient has rendez-vous today
        /// </summary>
        public bool HasRendezVous { get { return vHasRendezVous; } }
        #endregion
    }
}
