﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PhoenixUpdate.Class;
using System.Net;
using System.Diagnostics;

namespace PhoenixUpdate.GUI
{
    /// <summary>
    /// Main frame of the update module
    /// </summary>
    public partial class fr_Main : Form
    {
        #region Variables
        /// <summary>
        /// Handler to the ProgressBar update
        /// </summary>
        /// <param name="_ds">ProgressBar to update</param>
        protected delegate void UpdateGuiHandler(XmlUpdateEventArgs _Value);
        /// <summary>
        /// The methods for the update
        /// </summary>
        private UpdateGuiHandler UpdateGui;
        /// <summary>
        /// Update Manager
        /// </summary>
        XmlUpdateManager xu = new XmlUpdateManager();
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public fr_Main()
        {            
            InitializeComponent();
        }

        #endregion

        #region Events
        /// <summary>
        /// Click on the OK button
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_OK(object sender, EventArgs e)
        {
            //Launch Phoenix Suite
            Process.Start(xu.PhoenixPath + "\\PhoenixCommander.exe"); 

            this.Close();
        }
        /// <summary>
        /// Indicates changes in the update
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_UpdateChanged(object sender, XmlUpdateEventArgs e)
        {
            UpdateGui = new UpdateGuiHandler(RefreshProgressBar);
            UpdateGui(e);

            if (e.IsUpated)
                btn_Ok.Enabled = true;
        }
        /// <summary>
        /// The frame's loading
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Frame_Load(object sender, EventArgs e)
        {                        
            try
            {
                #region Kill Phoenix Suite
                Process[] Processes = Process.GetProcessesByName("PhoenixCommander");
                foreach (Process ps in Processes)
                    ps.Kill();
                tb_Log.Text = "Fermeture de Phoenix Suite.";
                #endregion

                xu.UpdateChanged += new OnUpdateChangedHandler(Event_UpdateChanged);
                xu.Fill();
                xu.Update();
                //xu.FinalizeUpdate();
            }
            catch (Exception ex)
            {
                tb_Log.AppendText("\r\nUne erreur est survenue:\r\n" + ex.Message);
                btn_Ok.Enabled = true;
            }
        }
        #endregion

        #region Methods
        /// <summary>
        /// Change the progress bar value
        /// </summary>
        /// <param name="_Data"></param>
        private void RefreshProgressBar(XmlUpdateEventArgs _Data)
        {
            if (_Data.IsDownloading)
            {
                pb_Progress.Value = _Data.DownloadPercentage;
                tb_Log.Text = _Data.MessageToDisplay;
            }
            else
                tb_Log.AppendText(_Data.MessageToDisplay);

        }
        /// <summary>
        /// Unactivate the closing cross
        /// </summary>
        protected override CreateParams CreateParams
        {
            get
            {
                CreateParams cp = base.CreateParams;
                cp.ClassStyle |= 0x0200;
                return cp;
            }
        }
        #endregion
    }
}
